@@ -481,7 +481,8 @@ def Entrenamiento(df2, t_s):
     Xrlinter_train, Xrlinter_test, yrlinter_train, yrlinter_test = train_test_split(Xrlinter, yrlinter, test_size=t_s)
     return Xrlinter_train, Xrlinter_test, yrlinter_train, yrlinter_test, Xrlinter
 
-def Escalas(cve, Xrlinter_train, Xrlinter_test):
+
+def Escalas(Xrlinter_train, Xrlinter_test):
     scl = StandardScaler().fit(Xrlinter_train)
     Xrlinter_train = scl.transform(Xrlinter_train)  
     Xrlinter_test = scl.transform(Xrlinter_test)  
@@ -501,19 +502,13 @@ def RForest(Xtrain,Xtest,ytrain,ytest,k):
     y_pred43 = cross_val_predict(rforest1, Xtest, np.ravel(ytest), cv=k)
     return rforest1,y_pred43
 
-def RForestEleccion(df2,cve,k):
+def RForestEleccion(df2,k):
     # Entrenamiento
     Xtodos_train, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
     # Escala
-    Xtodos_train, Xtodos_test,scl1 =Escalas(cve, Xtodos_train, Xtodos_test)
+    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train, Xtodos_test)
     # Random Forest
     rforest1,y_pred43=RForest(Xtodos_train,Xtodos_test,ytodos_train,ytodos_test,k)
-
-    #scaler1_file = "escalaRF_"+str(cve)+".save"
-    #joblib.dump(scl1, scaler1_file)
-    #print("El método de Random Forest se ha ejecutado con éxito. Se procederá a guardar los resultados.")
-    #joblib.dump(rforest1,"RForest_"+str(cve)+".joblib")
-    # (Esto se hace aparte)
     return scl1,ytodos_test,y_pred43,rforest1
 
 # XGB para un par de datos
@@ -530,11 +525,11 @@ def XGB(Xtrain,Xtest,ytrain,ytest,k):
     y_pred63 = cross_val_predict(search_model, Xtest, np.ravel(ytest), cv=k)
     return search_model,y_pred63
 
-def XGB_Eleccion(df2,cve,k):
+def XGB_Eleccion(df2,k):
     # Entrenamientos
     Xtodos_train, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
     # Escalas
-    Xtodos_train, Xtodos_test,scl1 =Escalas(cve, Xtodos_train, Xtodos_test)
+    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train, Xtodos_test)
     # XGBs
     xgb1,y_pred43=XGB(Xtodos_train,Xtodos_test,ytodos_train,ytodos_test,k)
 
@@ -652,8 +647,8 @@ def Rend_Est_AVM(reavm2):
     
 # Selección de datos del AVM para escalar
 def Xrl_inter(remL):
-    indexaciones=['ingreso','Index_antiguedad_10','longitud','latitud','supCSII','supTSII','avaluofiscal']
-    Xrlinter = np.array(remL[indexaciones])
+    reL=remL.drop(['valor'],axis=1)
+    Xrlinter = np.array(reL)
     return Xrlinter
 
 def SCL_model(scl,Xtodos,modelo):
